@@ -6,6 +6,18 @@ exports.render = function (req, res) {
     });
 
 }
+
+exports.ws = function (req, res) {
+   
+    req.ws.call("com.test.add",{x:2,y:3}).then(function(data){
+        req.ws.pub("com.test.hello",data);
+        res.send(data);
+    });
+
+}
+
+
+
 exports.db = function (req, res) {
     var r = req.r;
    console.log(req.x());
@@ -16,7 +28,8 @@ exports.db = function (req, res) {
    // console.log("xxx");
     //try {
        // r.db("oauth")
-            r.table("users")
+            r.table("users").coerceTo('Array')
+            .pager(req)
             .run()
             .then(function (data) {
                 x(data);
