@@ -5,14 +5,14 @@ var config = {
    // appKey: "5fc02522e60958787b8298067513c5f4b44ca78a",
     database: {
       db:'test',
-      host: '127.0.0.1',
+      host: '192.168.10.33',
       port: 28015,
       // user:"admin",
       // password:"next@2017"
     },
 
     ws:{
-       url: 'ws://127.0.0.1:8000/ws',
+       url: 'ws://192.168.10.33:8000/ws',
        realm: 'realm1'
     },
 
@@ -42,9 +42,9 @@ var config = {
       {
         name: "mssql",
         driver: "com.microsoft.sqlserver.jdbc.SQLServerDriver",
-        url: "jdbc:sqlserver://xxx:1433;databaseName=xx",
-        user: "xx",
-        password: "xxx"
+        url: "jdbc:sqlserver://10.3.231.39:1433;databaseName=edidb",
+        user: "edi",
+        password: "edi@2017"
       },
       {
         name: "oracle",
