@@ -9,7 +9,7 @@
     @Copyright (c) 2016-2017
 */
 
-const work_dir = process.cwd();
+//const work_dir = process.cwd();
 const route_dir = "/app/routes";
 var fs = require('fs');
 var express = require('express');
@@ -17,20 +17,16 @@ var URL = require('url');
 var logger = require('winston');
 var async = require('async');
 var fscan = require('./../common/fscan');
-const config = require(process.cwd() + '/config/config');
-//var passport = require('passport');
 
 
-var loadRouter = function (app, nylon_path, prefix, wd, rd, routes, callback) {
+var loadRouter = function (app, prefix, wd, rd, routes, callback) {
     async.each(routes, function (route, next) {
         try {
             var rname = route.replace(".routes.js", "");
             rname = rname.replace(wd, "");
             rname = rname.replace(rd, "");
             var router = express.Router();
-            //router.ws=app.ws;
-           // router.authenticate=app.nylon.authenticate
-            require(route)(router, nylon_path);
+            require(route)(router);
             if (prefix == "/api") {
                 app.use(prefix + rname, router);
             } else {
@@ -55,32 +51,14 @@ var loadRouter = function (app, nylon_path, prefix, wd, rd, routes, callback) {
 }
 
 module.exports = function (app) {
-    // app = require('./../routes/oauth.routes')(app, nylon_path);
-    //app = require('./../routes/pusher.routes')(app);
-    var db = app.nylon.r;
-    var nylon_path = app.nylon.nylon_path;
+    if( app.nylon.req.r){
+        //var req=app.nylon.req;
+       // var r=app.nylon.req.r;
 
-
-    //Object.assign({}, config.database,
-    //   { db: dbId, user: config.appId, password: config.appKey })
-
-
-    app.use(function (req, res, next) {
-
-        //   req.r = app.nylon.req.r;
-        //   console.log(app.nylon.req.r)
-        //req.logger = app.nylon.logger;
-
-        Object.assign(req, app.nylon.req);
-        Object.assign(res, app.nylon.res);
-      //    console.log(req.r);
-
-        req.r._Term.prototype.pager = function () {
-            // var url =req.baseUrl;// URL.parse(req.url, true).pathname;
-             //console.log(req);
+        app.nylon.req.r._Term.prototype.pager = function (req) {
+            var r=req.r;
              var limit = 50;
              var page = 1;
- 
              if (req.query._limit) {
                  limit = parseInt(req.query._limit);
                  page = parseInt(req.query._page);
@@ -96,8 +74,9 @@ module.exports = function (app) {
              var skip = (limit * (page - 1));
              var rowEnd = skip + limit;
              var rowStart = skip + 1;
- 
+    
              return this.do(function (data) {
+               //  var r=this;
                  return r.branch(
                      data.typeOf().eq('ARRAY'),
                      {
@@ -116,46 +95,28 @@ module.exports = function (app) {
                  )
              })
          };
+   
+    }
+    
+
+
+    app.use(function (req, res, next) {
+        Object.assign(req, app.nylon.req);
+        Object.assign(res, app.nylon.res);
+
+      
 
-        
         res.header("Access-Control-Allow-Origin", "*");
         res.header("Access-Control-Allow-Methods", "GET, POST, OPTIONS, PUT, DELETE");
         res.header("Access-Control-Allow-Headers", "Origin, X-Custom-Header, X-Requested-With, Content-Type, Accept, X-APP-ID, X-APP-KEY,X-CLIENT-ID,X-CLIENT-KEY, Authorization, token");
-
-        
         next();
     });
 
-    //  fscan.scan(nylon_path + "/lib/app/routes", ".routes.js", true, function (err, routes_root) {
-    //     loadRouter(app, nylon_path, "", nylon_path, "/lib/app/routes", routes_root, function (err, app) {
-
-    fscan.scan(work_dir + route_dir, ".routes.js", true, function (err, routes) {
-        loadRouter(app, nylon_path, "/api", work_dir, route_dir, routes, function (err, app) {
-            //callback(app);
-            
-            // app.use(express.static(work_dir + '/public'));
-            // app.use('/nylon', express.static(nylon_path + '/lib/public'));
-            // app.use(function (req, res, next) {
-            //     var ref = req.headers["referer"];
-            //     console.log(ref);
-            //     var url = URL.parse(req.url, true).pathname;
-            //     if (url.indexOf('api') < 0 && url.indexOf('.') < 0) {
-            //         res.status(200);
-            //         res.sendFile(work_dir + '/public/index.html', 200);
-            //     } else {
-            //         if (ref) {
-            //             next();
-            //         } else {
-            //             res.sendFile(work_dir + '/public/index.html', 200);
-            //         }
-
-            //     }
-            // });
+ 
+    fscan.scan(app.nylon.work_dir + route_dir, ".routes.js", true, function (err, routes) {
+        loadRouter(app, "/api", app.nylon.work_dir, route_dir, routes, function (err, app) {
+           
         });
     });
 
-    //  });
-    // });
-
-
 }
\ No newline at end of file
